import config from './config.js';
import store from './store/store.js';

const quickPhoneLogin = function(callbak) {
	var _this = this;
	uni.login({
		provider: 'univerify',
		univerifyStyle: { // 自定义登录框样式
			//参考`univerifyStyle 数据结构`
			"fullScreen": true,
			"icon": {
				"path": "static/images/logo.png" // 自定义显示在授权框中的logo，仅支持本地图片 默认显示App logo   
			},
			"authButton": {
				"normalColor": "#FCC353",
				"disabledColor": "#FCC353",
			},
			"slogan": {
				"color": "#8a8b90", //  slogan 字体颜色 默认值：#8a8b90  
			},
			"otherLoginButton": {
				"visible": true, // 是否显示其他登录按钮，默认值：true 
				"title": "其他号码登录",
			},
			"privacyTerms": {
				"defaultCheckBoxState": false, // 条款勾选框初始状态 默认值： true
				"uncheckedImage": "static/images/icon_agree.png", // 可选 条款勾选框未选中状态图片（仅支持本地图片 建议尺寸 24x24px）(3.2.0+ 版本支持)   
				"checkedImage": "static/images/icon_agree_act.png", // 可选 条款勾选框选中状态图片（仅支持本地图片 建议尺寸24x24px）(3.2.0+ 版本支持)   
				"checkBoxSize": 12, // 可选 条款勾选框大小，仅android支持
				"textColor": "#BBBBBB", // 文字颜色 默认值：#BBBBBB  
				"termsColor": "#ED2E32", //  协议文字颜色 默认值： #5496E3  
				"prefix": "我已阅读并同意", // 条款前的文案 默认值：“我已阅读并同意”  
				"suffix": "并使用本机号码登录", // 条款后的文案 默认值：“并使用本机号码登录”  
				"privacyItems": [ // 自定义协议条款，最大支持2个，需要同时设置url和title. 否则不生效
					{
						"url": "https://wxapp.honki.tech/h5/?id=6", // 点击跳转的协议详情页面  
						"title": "用户服务协议" // 协议名称  
					},
					{
						"url": "https://wxapp.honki.tech/h5/?id=5", // 点击跳转的协议详情页面  
						"title": "隐私协议" // 协议名称  
					}
				]
			},

		},
		success(res) { // 登录成功
			console.log("quickPhoneLogin", res
				.authResult); // {openid:'登录授权唯一标识',access_token:'接口返回的 token'}
			getCloudPhone(res.authResult.openid, res.authResult.access_token)
			callbak && callbak(res);
		},
		fail(res) { // 登录失败
			if (res.errCode == 30002) {
				//点击其他
				uni.navigateTo({
					url: '/pages/otherLogin/otherLogin',
				})
			} else if (res.errCode == 40201 || res.errCode == 30005) {
				//不支持
				uni.navigateTo({
					url: '/pages/otherLogin/otherLogin',
				})
			} else if (res.errCode == 30003) {

			} else {
				uni.navigateTo({
					url: '/pages/otherLogin/otherLogin',
				})
			}
			uni.closeAuthView()
			console.log(res.errCode)
			console.log(res.errMsg)
		}
	})
}

const getCloudPhone = function(openid, access_token) {
	var _this = this;
	uniCloud.callFunction({
		name: 'getUserPhone', // 你的云函数名称
		data: {
			'access_token': access_token, // 客户端一键登录接口返回的access_token
			'openid': openid, // 客户端一键登录接口返回的openid
			'platform': uni.getSystemInfoSync().platform
		}
	}).then(res => {
		console.log("getUserPhone success", res)
		// 登录成功，可以关闭一键登录授权界面了
		if (res.result.code == 1) {
			console.log("getUserPhone", res.result.data);
			var userInfo = res.result.data.user;
			var token = res.result.data.token;
			store.commit('setMember', userInfo);
			store.commit('setToken', token)
			uni.$emit('loginEvent', userInfo);
			if(userInfo.has_file){
				uni.$emit('addUserFileEvent', 1);
				uni.switchTab({
					url:'/pages/tab/home/home'
				})
			}else{
				uni.redirectTo({
				    url: '/pages/addFile/addFile?showJump=1'
				});
			}
		}
		uni.closeAuthView()
	}).catch(err => {
		// 处理错误
		console.log("getUserPhone err", err)
	})
}


const post = function(url, params) {
	if (!params) params = new Object;
	params.device = config.dev;
	params.app_id = config.appId;
	return new Promise((resolve, reject) => {
		uni.request({
			url: config.apiUrl + url, //仅为示例，并非真实接口地址。
			data: params,
			method: 'POST',
			success: (res) => {
				uni.hideLoading();
				if (res.statusCode == 200) {
					if (res.data.code == 100) { //未登录的情况
						store.commit('setMember', null);
						uni.removeStorageSync('member-token');
						reject({
							code: res.data.code,
							msg: res.data.msg
						});
					} else {
						resolve(res.data);
					}
				} else {

					uni.showToast({
						icon: 'none',
						title: "服务器繁忙,请重试"
					});
					reject({
						code: 500,
						msg: '服务器繁忙,请重试'
					});
				}
			},
			fail: (res) => {
				uni.hideLoading();
				uni.showToast({
					icon: 'none',
					title: "服务器繁忙,请重试"
				});
				reject({
					code: 500,
					msg: '服务器繁忙，请重试'
				});
			}
		});

	});
}


//需要登录的使用这个
const api = function(url, params, method, shutLogin) {
	if (!params) params = new Object;
		params.cdp = config.platform;
		params.cddId = config.deviceId;
		params.cdv = config.version;
		params.cdc = config.channel;
	var promise = new Promise((resolve, reject) => {
		var that = this;
		let token = uni.getStorageSync('member-token');
		console.log("token", token)
		var header = {
			// 'content-type': 'application/x-www-form-urlencoded',
		};
		if (token) {
			header.authorization = 'UUID|' + token
		}
		//网络请求
		uni.request({
			url: config.apiUrl + url,
			data: params,
			method: method,
			header: header,
			timeout: 6000,
			success: function(res) { //服务器返回数据
			console.log('服务器返回数据', res)
				if (res.statusCode == 200) {
					if (res.data.code == 400) {
						//登录失效
						console.log('quickPhoneLogin', shutLogin)
						if (!shutLogin) {
							quickPhoneLogin();
						}
					}else if (res.data.code == 300||res.data.code == 301) {
						//清除数据，跳转到首页
						store.commit('setMember', {});
						store.commit('setToken', null)
						reject(res.data.message);
					}
					resolve(res.data);
				} else { //返回错误提示信息
					console.log('request error', res)
					uni.showToast({
						title: res.data.message ? res.data.message : '请求失败',
						icon: 'none',
						duration: 2000
					})
				}
			},
			fail: function(e) {
				uni.hideLoading();
				console.log('后端故障', e)
				reject(e)
			},
			error: function(e) {
				console.log('error',e)
				uni.hideLoading();
				reject('网络出错');
			}
		})
	});
	return promise;
}


const upload = function(url, src,formData, shutLogin) {
	var promise = new Promise((resolve, reject) => {
		var that = this;
		let token = uni.getStorageSync('member-token');
		console.log("token", token)
		var header = {
			// 'content-type': 'application/x-www-form-urlencoded',
		};
		if (token) {
			header.authorization = 'UUID|' + token
		}
		if (!formData) formData = new Object;
		//网络请求
		uni.uploadFile({
			url: config.apiUrl + url,
			filePath: src,
			name: 'file',
			formData:formData,
			header: header,
			timeout: 6000,
			success: function(res) { //服务器返回数据
				console.log('upload', res)
				uni.hideLoading();
				if (res.statusCode == 200) {
					if (res.data.code == 400) {
						//登录失效
						if (!shutLogin) {
							quickPhoneLogin();
						}
					}
					resolve(JSON.parse(res.data));
				} else { //返回错误提示信息
					console.log('request error', res)
					uni.showToast({
						title: res.data.message ? res.data.message : '请求失败',
						icon: 'none',
						duration: 2000
					})
				}
			},
			fail: function(e) {
				uni.hideLoading();
				console.log('后端故障', e)
				reject(e)
			},
			error: function(e) {
				uni.hideLoading();
				reject('网络出错');
			}
		})
	});
	return promise;
}

const appv = function(params) {
	if (!params) params = new Object;
	let url = config.apiUrl + '/app/appv';
	uni.request({
		url: url,
		data: params,
		method: 'POST',
		success() {
			console.log('日志写入成功');
		},
		fail(e) {
			console.log('日志写入失败', e);
		},
	});
}

const kefuApi = function(tag) {
	const system = uni.getSystemInfoSync();
	let params = {
		deviceId:system.deviceId,
		brand: system.brand,
		model: system.model,
		system: system.system,
		platform: system.platform,
		tag:tag
	}
	var header = {
		
	};
	let url = config.apiUrl + '/app/kefuApi';
	let token = uni.getStorageSync('member-token');
	if (token) {
		header.authorization = 'UUID|' + token
	}
	params.platform = config.platform;
	params.deviceId = config.deviceId;
	params.version = config.version;
	params.channel = config.channel;
	uni.request({
		url: url,
		data: params,
		method: 'POST',
		header: header,
		success() {
		},
		fail(e) {
		},
	});
}

export default {
	post,
	api,
	upload,
	quickPhoneLogin,
	appv,
	kefuApi
}
